@@ -10,6 +10,7 @@
 #' @param lkm Distance of link (km)
 #' @param alpha Parameter of BPR curves
 #' @param beta Parameter of BPR curves
+#' @param net SpatialLinesDataFrame or Spatial Feature of "LINESTRING"
 #' @param scheme Logical to create a Speed data-frame with 24 hours and a
 #' default  profile. It needs ffs and ps:
 #' \tabular{rl}{
@@ -21,28 +22,40 @@
 #'   20:00-22:00 \tab average between ffs and ps\cr
 #'   22:00-00:00 \tab ffs\cr
 #' }
-#' @param distance Character specifying the units for distance. Default is "km"
-#' @param time Character specifying the units for time Default is "h".
+#' @param distance Deprecated. Character specifying the units for distance.
+#' Default is "km"
+#' @param time Deprecated. Character specifying the units for time Default is "h".
 #' @param isList Deprecated
-#' @return dataframe speeds with units.
+#' @return dataframe speeds with units or sf.
+#' @importFrom sf st_sf st_as_sf
 #' @export
 #' @examples {
 #' data(net)
 #' data(pc_profile)
 #' pc_week <- temp_fact(net$ldv+net$hdv, pc_profile)
-#' df <- netspeed(pc_week, net$ps, net$ffs, net$capacity, net$lkm)
+#' df <- netspeed(pc_week, net$ps, net$ffs, net$capacity, net$lkm, alpha = 1)
 #' class(df)
 #' plot(df) #plot of the average speed at each hour, +- sd
 #' df <- netspeed(ps = net$ps, ffs = net$ffs, scheme = TRUE)
 #' class(df)
 #' plot(df) #plot of the average speed at each hour, +- sd
+#' dfsf <- netspeed(ps = net$ps, ffs = net$ffs, scheme = TRUE, net = net)
+#' class(dfsf)
+#' head(dfsf)
+#' plot(dfsf) #plot of the average speed at each hour, +- sd
 #' }
 netspeed <- function (q = 1, ps, ffs, cap, lkm, alpha = 0.15, beta = 4,
-                      scheme = FALSE,
+                      net, scheme = FALSE,
                       distance = "km", time="h", isList){
   if(!missing(isList)){
     .Deprecated(msg = "'isList' argument is deprecated")
-  } else if (scheme == FALSE & missing(q)){
+  } else if(!missing(distance)){
+    .Deprecated(msg = "'distance' argument is deprecated")
+  } else if(!missing(time)){
+    .Deprecated(msg = "'time' argument is deprecated")
+  }
+
+  if (scheme == FALSE & missing(q)){
     stop("No vehicles on 'q'")
   } else if (scheme == FALSE & !missing(q)){
     qq <- as.data.frame(q)
@@ -57,8 +70,14 @@ netspeed <- function (q = 1, ps, ffs, cap, lkm, alpha = 0.15, beta = 4,
       lkm/(lkm/ffs*(1 + alpha*(qq[,i]/cap)^beta))
     }))))
     names(dfv) <- unlist(lapply(1:ncol(q), function(i) paste0("S",i)))
-    dfv <- Speed(dfv, distance = distance, time = time)
-    return(dfv)
+    df_scheme <- Speed(dfv, distance = distance, time = time)
+    if(!missing(net)){
+      netsf <- sf::st_as_sf(net)
+      df_schemesf <- sf::st_sf(df_scheme, geometry = netsf$geometry)
+      return(df_schemesf)
+    } else {
+      return(df_scheme)
+    }
   } else {
     ps <- as.numeric(ps)
     ffs <- as.numeric(ffs)
@@ -68,7 +87,14 @@ netspeed <- function (q = 1, ps, ffs, cap, lkm, alpha = 0.15, beta = 4,
                  replicate(3, ffs))
     names(dfv) <- c(rep("FSS",5), "AS", rep("PS", 3), rep("AS", 7),
                     rep("PS", 3), rep("AS", 2),rep("FSS",3))
-    dfv <- Speed(as.data.frame(dfv), distance = distance, time = time)
-    return(dfv)
+    df_speed <- Speed(as.data.frame(dfv), distance = distance, time = time)
+
+  if(!missing(net)){
+    netsf <- sf::st_as_sf(net)
+    df_speedsf <- sf::st_sf(df_speed, geometry = netsf$geometry)
+    return(df_speedsf)
+  } else {
+    return(df_speed)
+  }
   }
 }
